@@ -15,10 +15,10 @@
 #' @param date A date/string formatted as YYYYMMDD.
 #' @param forecast_time a string indicating which time of day UTC the
 #' forecast is from. Options are "0000", "0600", "1200", "1800".
-#' @param ens_idx sequential list of ensembles to fetch. Default is all 21.
+#' @param ens,ens_idx sequential list of ensembles to fetch. Default is all 21.
 #' Note that the ensembles are labelled 0-20, so ens_idx=1:3 will return
 #' ensembles 0, 1, and 2.
-#' @param time_idx sequential list of time increments to return. List is the
+#' @param time,time_idx sequential list of time increments to return. List is the
 #' index of times, which are in 6 hour increments. (e.g. c(1,2) fetches the
 #' 6 and 12 hour forecast.)
 #' @param dims (not implemented) indices for additional dimensions to be
@@ -58,24 +58,24 @@
 #'
 #' #Get forecast for a certain variable.
 #' forecast <- gefs("Total_precipitation_surface_6_Hour_Accumulation_ens",
-#'   lat, lon)
+#'   lat, lon, ens = 0, time = 12)
 #'
 #' #Fetch a different date (available up to 10 days prior to today)
 #' forecast_yesterday_prec <- gefs(
 #'    "Total_precipitation_surface_6_Hour_Accumulation_ens",
-#'    lat, lon, date=format(as.Date(Sys.time()) - 1, "%Y%m%d"))
+#'    lat, lon, ens = 1, time = 6, date=format(as.Date(Sys.time()) - 1, "%Y%m%d"))
 #'
 #' #specific ensemble and times, for the 1800 forecast.
 #' # here ensembles 1-3 (ensembles are numbered starting with 0)
-#' # and time for 2 days from today at 1800
+#' # and two time periods: c(1800, 2400)
 #' date <- format(as.Date(Sys.time()) - 1, "%Y%m%d")
 #' var <- "Temperature_height_above_ground_ens"
-#' gefs(var, lat, lon, date = date, forecast_time = "1800", ens_idx=2:4,
-#'   time_idx=1:8)
+#' gefs(var, lat, lon, date = date, forecast_time = "1800", ens=1:3,
+#'   time=6*(3:4))
 #'
 #' #One ensemble, all latitudes and longitudes (this is a big file) for the
 #' # next 3 days.
-#' # gefs(var, ens=1, time=1:12)
+#' # gefs(var, ens=1, time=6*(1:12))
 #' }
 #'
 gefs <- function(var, lat, lon, ...) {
@@ -107,11 +107,11 @@ gefs_CONNECT <- function(date = format(Sys.time(), "%Y%m%d"),
 }
 
 #' @rdname gefs
-gefs_GET <- function(var, lat, lon,
+gefs_GET <- function(var, lat = NULL, lon = NULL, ens = NULL, time = NULL,
                      date = format(Sys.time(), "%Y%m%d"),
                      forecast_time = c("0000", "0600", "1200", "1800"),
-                     ens_idx = 1:21,
-                     time_idx = 1:65,
+                     ens_idx = NULL, # will be removed in future version
+                     time_idx = NULL, # will be removed in future version
                      dims = NULL,
                      raw = FALSE,
                      ...) {
@@ -147,24 +147,42 @@ gefs_GET <- function(var, lat, lon,
   n_time <- varsize[ndims] #time is always the last dimension
 
   # Set the indices for each dimension
+  dim_names <- sapply(v$dim, function(d) { d$name })
   dim_idxs <- list()
   for (i in 1:length(v$dim)) {
     dn <- v$dim[[i]]$name
     if(dn == "lon") {
-      dim_idxs[[i]] <- if(!missing(lon)) which(v$dim[[i]]$vals %in% (round(lon,0) %% 360)) else 1:v$dim[[i]]$len
+      dim_idxs[[i]] <- if(!is.null(lon)) which(v$dim[[i]]$vals %in% (round(lon,0) %% 360)) else 1:v$dim[[i]]$len
     } else if (dn == "lat") {
-      dim_idxs[[i]] <- if(!missing(lat)) which(v$dim[[2]]$vals %in% round(lat, 0)) else 1:v$dim[[2]]$len
+      dim_idxs[[i]] <- if(!is.null(lat)) which(v$dim[[i]]$vals %in% round(lat, 0)) else 1:v$dim[[i]]$len
     } else if (dn == "ens") {
-      dim_idxs[[i]] <- ens_idx
-    } else if (dn %in% c("time1", "time2")) {
-      dim_idxs[[i]] <- time_idx
+      dim_idxs[[i]] <- if(!is.null(ens)) which(v$dim[[i]]$vals %in% ens) else 1:v$dim[[i]]$len
+    } else if (dn %in% c("time", "time1", "time2")) {
+      dim_idxs[[i]] <- if(!is.null(ens)) which(v$dim[[i]]$vals %in% time) else 1:v$dim[[i]]$len
     } else if (dn %in% names(additional_dims)) {
       dim_idxs[[i]] <- which(v$dim[[i]]$vals %in% additional_dims[[dn]])
     } else {
       dim_idxs[[i]] <- 1:v$dim[[i]]$len
     }
   }
-  names(dim_idxs) <- lapply(1:length(v$dim), function(i) { v$dim[[i]]$name })
+  names(dim_idxs) <- dim_names
+
+  # Assign ens_idx and time_idx if used
+  if(!is.null(ens_idx)) {
+    d_idx <- which(dim_names == "ens")
+    if(!is.null(ens_idx)) message("'ens_idx' is deprecated and will be removed in future versions, please specify values (not indices) in 'ens' instead.")
+    if(!any(ens_idx %in% 1:v$dim[[d_idx]]$len)) stop("'ens_idx' is out of bounds, check the dimension values with 'gefs_dimension_values(dim = 'ens').")
+    dim_idxs[['ens']] <- ens_idx
+  }
+  if(!is.null(time_idx)) {
+    time_name <- grep("time", dim_names, value = TRUE)
+    d_idx <- which(dim_names %in% time_name)
+    if(!is.null(time_idx)) message("'time_idx' is deprecated and will be removed in future versions, please specify values (not indices) in 'time' instead.")
+    if(!any(time_idx %in% 1:v$dim[[d_idx]]$len)) stop("'time_idx' is out of bounds, check the dimension values with 'gefs_dimension_values(dim = 'time').")
+    dim_idxs[[time_name]] <- time_idx
+  }
+
+
 
   #start indices of dimensions to read from data
   start <- sapply(dim_idxs, function(d) { min(d) })
@@ -189,7 +207,7 @@ gefs_GET <- function(var, lat, lon,
   forecast_time <- strsplit(fname, ".grib2")[[8]]
   list(forecast_date = date,
        forecast_time = forecast_time,
-       dimensions    = dims,
+       dimensions    = names(dim_idxs),
        data          = d)
 }
 
@@ -228,9 +246,31 @@ gefs_dimensions <- function(con = NULL, ...) {
 #'
 #' @param dim (character) the dimension.
 #' @rdname gefs
-gefs_dimension_values <- function(dim, con = NULL, ...) {
-  if (is.null(dim) || missing(dim)) stop("dim cannot be NULL or missing.")
+gefs_dimension_values <- function(dim, var = NULL, con = NULL, ...) {
+  if (missing(dim)) stop("dim cannot be NULL or missing.")
   if (is.null(con)) con = gefs_CONNECT(...)
-  con$dim[[dim]]$vals
+
+  if (!(dim %in% names(con$dim))) {
+    stop(paste0(dim, " is not a valid GEFS dimension. Check with 'gefs_dimensions()'."))
+  }
+
+  if (!is.null(var)) {
+    v <- con$var[[var]]
+    dim_names <- sapply(v$dim, function(d) { d$name })
+
+    # there are multiple "time" dimensions, so get the one for this variable
+    if(dim == "time") dim <- grep("time", dim_names, value = TRUE)
+
+    if(!(dim %in% dim_names)) stop(paste0(dim,
+                                          " is not in variable dimensions: ",
+                                         paste0(dim_names, collapse = ", "),
+                                         "."))
+
+    dim_idx <- which(dim_names == dim)
+    res = con$var[[var]]$dim[[dim_idx]]$vals
+  } else {
+    res <- con$dim[[dim]]$vals
+  }
+  res
 }
 
