@@ -2,32 +2,32 @@
 #'
 #' @export
 #' @param refresh (logical) Download station data from NOAA ftp server again.
-#' Default: \code{FALSE}
+#' Default: `FALSE`
 #'
 #' @references ftp://ftp.ncdc.noaa.gov/pub/data/noaa/
 #' @family isd
 #' @details The data table is cached, but you can force download of data from NOAA
-#' by setting \code{refresh=TRUE}
+#' by setting `refresh=TRUE`
 #' @return a tibble (data.frame) with the columns:
-#' \itemize{
-#'  \item usaf - USAF number, character
-#'  \item wban - WBAN number, character
-#'  \item station_name - station name, character
-#'  \item ctry - Country, if given, character
-#'  \item state - State, if given, character
-#'  \item icao - ICAO number, if given, character
-#'  \item lat - Latitude, if given, numeric
-#'  \item lon - Longitude, if given, numeric
-#'  \item elev_m - Elevation, if given, numeric
-#'  \item begin - Begin date of data coverage, of form YYYYMMDD, numeric
-#'  \item end - End date of data coverage, of form YYYYMMDD, numeric
-#' }
+#'
+#' - usaf - USAF number, character
+#' - wban - WBAN number, character
+#' - station_name - station name, character
+#' - ctry - Country, if given, character
+#' - state - State, if given, character
+#' - icao - ICAO number, if given, character
+#' - lat - Latitude, if given, numeric
+#' - lon - Longitude, if given, numeric
+#' - elev_m - Elevation, if given, numeric
+#' - begin - Begin date of data coverage, of form YYYYMMDD, numeric
+#' - end - End date of data coverage, of form YYYYMMDD, numeric
+#'
 #'
 #' @section File storage:
 #' We use \pkg{rappdirs} to store files, see
-#' \code{\link[rappdirs]{user_cache_dir}} for how we determine the directory on
+#' [rappdirs::user_cache_dir()] for how we determine the directory on
 #' your machine to save files to, and run
-#' \code{rappdirs::user_cache_dir("rnoaa")} to get that directory.
+#' `rappdirs::user_cache_dir("rnoaa")` to get that directory.
 #'
 #' @examples \dontrun{
 #' # Get station table
@@ -58,8 +58,8 @@ isd_stations <- function(refresh = FALSE) {
     dat <- stats::setNames(df, gsub("_$", "", gsub("\\.", "_", tolower(names(df)))))
     if (!file.exists(basedir)) dir.create(basedir, recursive = TRUE)
     saveRDS(dat, file = path)
-    as_data_frame(dat)
+    as_tibble(dat)
   } else {
-    as_data_frame(readRDS(path))
+    as_tibble(readRDS(path))
   }
 }
