@@ -61,4 +61,12 @@ test_that("cpc_prcp fails well", {
                "date must be of class character, Date")
   expect_error(cpc_prcp("2017-01-15", us = 5),
                "us must be of class logical")
+
+  # acceptable years
+  ## non us
+  expect_error(cpc_prcp("1945-01-01"), "must be between")
+  expect_error(cpc_prcp(Sys.Date() + 365), "must be between")
+  ## us
+  expect_error(cpc_prcp("1947-12-31", us = TRUE), "must be between")
+  expect_error(cpc_prcp(Sys.Date() + 365, us = TRUE), "must be between")
 })
